@@ -91,7 +91,7 @@ class ArcaAPI():
         a = self.curSession.post(URL, data=payload)
         self.check_for_error(a)
 
-    def post_article(self, channel, name, content, category=None, copy_humor=False):
+    def post_article(self, channel, name, content, category=None, copy_humor=False, agree_prevent_delete=False):
         URL = 'https://arca.live/b/' + channel + '/write'
         csrf = self.getcsrf(URL)
         payload = {'_csrf': csrf[0],
@@ -103,6 +103,8 @@ class ArcaAPI():
                    }
         if copy_humor:
             payload['copyHumorArticle'] = 'on'
+        if agree_prevent_delete:
+            payload['agreePreventDelete'] = 'on'
         a = self.curSession.post(URL, data=payload)
         self.check_for_error(a)
 
